# STAR Docker images

We build two Docker images that provide the STAR aligner. The first image is a base image containing the software. The second image uses the base image to build the indexes and include them.
